| Package: |
| klin |
| Type: |
| Package |
| Version: |
| 2007-01-08 |
| Date: |
| 2007-01-08 |
| License: |
| GPL version 2 or newer |
The most important functions are klin.eval and klin.solve,
which evaluate A %*% x or solve for x in A %*% x
== b where A is a Kronecker product and x and b
are conforming vectors.
Convenience functions for solving least squares problems with Kronecker
structure (klin.ls and klin.preparels) are also included.
The function klin.klist forms the Kronecker product of a list of
matrices.