Learn R Programming

klin (version 2007-02-05)

klin.klist: Calculates the Kronecker product of a list of matrices

Description

Given a list A of matrices, the function calculates A[[1]] %x% ... %x% A[[length(A)]].

Usage

klin.klist(A)

Arguments

A
A list that contains the matrices, preferably of class Matrix.

Value

A matrix, the dimensions are the product of the dimensions of the matrices in A.

See Also

klin.eval, klin.solve, klin.ls, klin.preparels.